@@ -47,7 +47,7 @@ fix <- function (list, names, defaults = NULL) {
 
 		if (0 < length(wnames)) { #if wrong names in original list
 
-			return(value = NULL, msg = paste0("has unknown component ", wnames, ". Names of design components can only be resource, cols, style, sep, brackets and rm_empty_cols\n"))
+			return(list(value = NULL, msg = paste0("has unknown component ", wnames, ". Names of design components can only be resource, cols, style, sep, brackets and rm_empty_cols\n")))
 
 		}
 
@@ -60,8 +60,10 @@ fix <- function (list, names, defaults = NULL) {
 	#set defaults
 	if (!is.null(defaults)) {
 		for (i in seq_along(list)) {
-			if (is.null(list[[i]]))
+			if (is.null(list[[i]])&&!is.null(defaults[[i]])){
 				list[[i]] <- defaults[[i]]
+			}
+
 		}
 	}
 
@@ -131,7 +133,7 @@ fix_df_desc <- function (df_desc) {
 
 	}else{
 
-		fix_res <- fix(df_desc$style,c("sep", "brackets", "rm_empty_cols"))
+		fix_res <- fix(df_desc$style,c("sep", "brackets", "rm_empty_cols"), defaults = list(" ", NULL, TRUE))
 
 		if(is.null(fix_res$value)){
 
@@ -393,7 +395,7 @@ add_attribute_to_design <- function(design, attrib = "value") {
 
 		if (!is.null(design[[n_d]]$cols)) { #Only add attrib if xpath expressions are provided
 
-			if (1 < length(design[[n_d]]$cols)) { #when several expressions are provided
+			if (is.list(design[[n_d]]$cols)) { #when cols are provided as list
 
 				for (n_c in names(design[[n_d]]$cols)) { #loop through cols
 					txt <- design[[n_d]]$cols[[n_c]]
@@ -404,7 +406,7 @@ add_attribute_to_design <- function(design, attrib = "value") {
 					}
 				}
 
-			} else { #wenn cols is just on expression
+			} else { #wenn cols is just one expression
 
 				txt <- design[[n_d]]$cols
 				if (length(grep("/@(\\w|\\*)+$", txt)) < 1) {
